@@ -47,7 +47,9 @@ class Annotation(object):
         """
 
         chunk_feature_locs = sorted(
-            chunk_feature_locs, key=lambda t: (t[0].feature.id, t[1].base_first)
+            chunk_feature_locs,
+            key=lambda t: (t[0].feature.id, t[1].base_first,
+                           t[0].feature.strand * t[0].feature_base_first)
         )
 
         annotations = []
@@ -55,12 +57,18 @@ class Annotation(object):
             if (
                 len(annotations) > 0
                 and annotations[-1].feature.id == cf.feature_id
-                and annotations[-1].feature_base_last == cf.feature_base_first - 1
+                and ((annotations[-1].feature.strand > 0
+                      and annotations[-1].feature_base_last == cf.feature_base_first - 1)
+                     or (annotations[-1].feature.strand < 0
+                         and annotations[-1].feature_base_first == cf.feature_base_last + 1))
                 and annotations[-1].base_last == fcl.base_first - 1
             ):
                 # merge annotation
                 annotations[-1].base_last = fcl.base_last
-                annotations[-1].feature_base_last = cf.feature_base_last
+                if annotations[-1].feature.strand > 0:
+                    annotations[-1].feature_base_last = cf.feature_base_last
+                else:
+                    annotations[-1].feature_base_first = cf.feature_base_first
             else:
                 annotations.append(
                     Annotation(
